---
title: 카카오페이 상점아이디 추가 절차
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 서비스 추가/변경
seo:
  title: 카카오페이 상점아이디 추가 절차
  description: >-
    카카오페이의 상점아이디(사이트코드) 추가절차 안내입니다. 추가 상점아이디는 포트원 호스팅사를 기준으로 수수료가 적용되며, 상점아이디를
    추가하실 수 있는 경우를 확인하세요.
  keywords:
    - 카카오페이
    - 서비스추가/변경
tags:
  - 카카오페이
  - 서비스추가/변경
pgCompanies:
  - 카카오페이
searchTags:
  - 카카오페이
  - 카카오페이 사이트추가
  - 카카오페이 사이트 추가
  - 사이트 추가
  - 서비스 추가
  - 사이트추가
  - 서비스추가
  - 상점아이디
  - MID
  - CID
  - 상점아이디 추가
  - 카카오페이 상점아이디추가
  - 카카오페이 상점아이디 추가
  - CID추가
  - 상점아이디추가
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="카카오페이 상점아이디 추가 절차를 안내해드립니다. 추가되는 상점아이디는 포트원 호스팅사를 기준으로 수수료가 적용되는 점 참고해주세요." />

<Callout title="포트원 기준 결제대행사 수수료 보러가기↗" />

### **상점아이디 추가 케이스**

<Callout content="1. 카카오페이의 상점아이디 추가 절차는 신규 계약절차와 동일하게 진행됩니다.
2. 포트원 정책에 의하여 기존에 포트원을 통하지 않고 계약된 상점아이디는 포트원 서비스 사용이 불가합니다. 새로운 포트원용 상점아이디를 추가 발급 받으신 후 이용해주시기 바랍니다." title="참고사항" icon="💡" />

- 이미 카카오페이와 직접 계약이 되어있다가 포트원으로 연동하고자 하시는 경우
- 새로운 서비스가 추가되는 경우 (=심사를 다시 받아야 하는 경우)
- 기존 서비스와 결제/정산을 분리하고자 하시는 경우
- 심사받은 적 없는 연동방식을 추가하시는 경우 (ex. 일반결제 사용중에 정기결제 추가시)

### **신청방법**

#### **신청 경로**

- [포트원 관리자콘솔↗ ](https://admin.portone.io/) 회원가입 및 로그인  > 좌측 상단 \[전자결제 신청] 버튼 클릭 > 사업자등록증 업로드(이미 진행 했을시 생략) 및 결제수단 담기 > 접수완료

<Callout title="카카오페이 상세 계약절차 보러가기↗" />
